Package: nflreadr
Title: Download 'nflverse' Data
Version: 1.5.1
Authors@R: c(
    person("Tan", "Ho", , "tan@tanho.ca", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0001-8388-5155")),
    person("Sebastian", "Carl", , "mrcaseb@gmail.com", role = "aut"),
    person("John", "Edwards", , "edwards1860@gmail.com", role = "ctb"),
    person("Ben", "Baldwin", , "bbaldwin206@gmail.com", role = "ctb"),
    person("Thomas", "Mock", role = "ctb"),
    person("Lee", "Sharpe", role = "ctb"),
    person("Pranav", "Rajaram", , "pranavrajaram@gmail.com", role = "ctb")
  )
Description: A minimal package for downloading data from 'GitHub'
    repositories of the 'nflverse' project.
License: MIT + file LICENSE
URL: https://nflreadr.nflverse.com,
        https://github.com/nflverse/nflreadr
BugReports: https://github.com/nflverse/nflreadr/issues
Depends: R (>= 4.1.0)
Imports: cachem (>= 1.0.0), cli (>= 3.0.0), curl (>= 4.3.0), data.table
        (>= 1.14.0), glue (>= 1.4.0), lifecycle, memoise (>= 2.0.0),
        methods, rappdirs (>= 0.3.0), rlang (>= 0.4.10), tools, utils
Suggests: arrow (>= 6.0.0), covr (>= 3.0.0), DT (>= 0.15.0), fs (>=
        1.5.0), gh (>= 1.0.0), knitr (>= 1.0.0), piggyback (>= 0.1.2),
        progressr (>= 0.8.0), rmarkdown (>= 2.6.0), stringi, testthat
        (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-13 18:23:38 UTC; tan
Author: Tan Ho [aut, cre, cph] (ORCID: <https://orcid.org/0000-0001-8388-5155>),
  Sebastian Carl [aut],
  John Edwards [ctb],
  Ben Baldwin [ctb],
  Thomas Mock [ctb],
  Lee Sharpe [ctb],
  Pranav Rajaram [ctb]
Maintainer: Tan Ho <tan@tanho.ca>
Repository: CRAN
Date/Publication: 2026-04-13 19:30:02 UTC
Built: R 4.5.2; ; 2026-04-15 04:58:56 UTC; unix
