---
title: "Data Dictionary - Combine"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Data Dictionary - Combine}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  echo = FALSE,
  comment = "#>"
)
```

```{r }
knitr::kable(nflreadr::dictionary_combine)
```

