---
title: "Data Dictionary - Schedules"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Data Dictionary - Schedules}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  echo = FALSE,
  comment = "#>"
)
use_dt <- FALSE
if(requireNamespace("DT", quietly = TRUE)) use_dt <- TRUE
```
```{r eval = use_dt}
DT::datatable(nflreadr::dictionary_schedules,
              options = list(scrollX = TRUE, pageLength = 25),
              filter = "top",
              rownames = FALSE
              )
```
```{r eval = !use_dt}
knitr::kable(nflreadr::dictionary_schedules)
```
